==> client-sdk-react-0.59.0.tgz: package/src/components/RoomControls/RoomControls.tsx <==
import React from 'react'
import './RoomControls.scss'
import { ZocksMediaActions } from '../../models'
import classNames from 'classnames'
import { useRoomControls } from './hooks'
import { DeviceSelectButton } from '../DeviceSelectButton'

export const RoomControls: React.FC<{
  mediaActions: ZocksMediaActions
  leaveAction: () => void
}> = ({ mediaActions, leaveAction }) => {
  const {
    audioIsOn,
    videoIsOn,
    isScreenSharing,
    isLocalScreenShare,
    toggleAudio,
    toggleVideo,
    selectAudioDevice,
    selectVideoDevice,
  } = useRoomControls(mediaActions)

  return (
    <div className='room-controls'>
      <div className='room-controls__audio-button-container'>
        <button id='room-controls__audio-button' className='room-controls__control-button' onClick={toggleAudio}>
          <div
            className={classNames({
              'room-controls__audio-button--unmuted': audioIsOn,
              'room-controls__audio-button--muted': !audioIsOn,
            })}
          />
          <label htmlFor='room-controls__audio-button'>{audioIsOn ? 'Mute' : 'Unmute'}</label>
        </button>
        <DeviceSelectButton
          className='room-controls--audio-select-button'
          deviceKind={'audioinput'}
          onDeviceSelected={selectAudioDevice}
          label={'Audio devices'}
        />
      </div>
      <div className='room-controls__video-button-container'>
        <button id='room-controls__video-button' className='room-controls__control-button' onClick={toggleVideo}>
          <div
            className={classNames({
              'room-controls__video-button--unmuted': videoIsOn,
              'room-controls__video-button--muted': !videoIsOn,
            })}
          />
          <label htmlFor='room-controls__video-button'>{videoIsOn ? 'Disable Video' : 'Enable Video'}</label>
        </button>
        <DeviceSelectButton
          className='room-controls--video-select-button'
          deviceKind={'videoinput'}
          onDeviceSelected={selectVideoDevice}
          label={'Video devices'}
        />
      </div>

      <button
        disabled={isScreenSharing && !isLocalScreenShare}
        id='room-controls__screen-share-button'
        className='room-controls__control-button room-controls__screen-share-button'
        onClick={isScreenSharing ? mediaActions.unPublishScreenShare : mediaActions.publishScreenShare}
      >
        <div
          className={classNames({
            'room-controls__screen-share-button--share-on': !isScreenSharing || !isLocalScreenShare,
            'room-controls__screen-share-button--share-off': isScreenSharing && isLocalScreenShare,
          })}
        />
        <label htmlFor='room-controls__screen-share-button'>
          {isLocalScreenShare ? 'Stop Sharing' : 'Share Screen'}
        </label>
      </button>
      <button className='room-controls__leave-button' onClick={leaveAction}>
        Leave
      </button>
    </div>
  )
}

==> client-sdk-react-1.1.2.tgz: package/src/components/RoomControls/RoomControls.tsx <==
import React from 'react'
import './RoomControls.scss'
import classNames from 'classnames'
import { useRoomControls } from './hooks'
import { DeviceSelectButton } from '../DeviceSelectButton'
import { ZocksMediaActions } from '../../store'

export const RoomControls: React.FC<{
  mediaActions: ZocksMediaActions
  leaveAction: () => void
}> = ({ mediaActions, leaveAction }) => {
  const {
    audioIsOn,
    videoIsOn,
    isScreenSharing,
    isLocalScreenShare,
    toggleAudio,
    toggleVideo,
    selectAudioDevice,
    selectVideoDevice,
  } = useRoomControls(mediaActions)

  return (
    <>
      <div className='room-controls__audio-button-container'>
        <button id='room-controls__audio-button' className='room-controls__control-button' onClick={toggleAudio}>
          <div
            className={classNames({
              'room-controls__audio-button--unmuted': audioIsOn,
              'room-controls__audio-button--muted': !audioIsOn,
            })}
          />
          <label htmlFor='room-controls__audio-button'>{audioIsOn ? 'Mute' : 'Unmute'}</label>
        </button>
        <DeviceSelectButton
          className='room-controls--audio-select-button'
          deviceKind={'audioinput'}
          onDeviceSelected={selectAudioDevice}
          label={'Audio devices'}
        />
      </div>
      <div className='room-controls__video-button-container'>
        <button id='room-controls__video-button' className='room-controls__control-button' onClick={toggleVideo}>
          <div
            className={classNames({
              'room-controls__video-button--unmuted': videoIsOn,
              'room-controls__video-button--muted': !videoIsOn,
            })}
          />
          <label htmlFor='room-controls__video-button'>{videoIsOn ? 'Disable Video' : 'Enable Video'}</label>
        </button>
        <DeviceSelectButton
          className='room-controls--video-select-button'
          deviceKind={'videoinput'}
          onDeviceSelected={selectVideoDevice}
          label={'Video devices'}
        />
      </div>

      <button
        disabled={isScreenSharing && !isLocalScreenShare}
        id='room-controls__screen-share-button'
        className='room-controls__control-button room-controls__screen-share-button'
        onClick={isScreenSharing ? mediaActions.unPublishScreenShare : mediaActions.publishScreenShare}
      >
        <div
          className={classNames({
            'room-controls__screen-share-button--share-on': !isScreenSharing || !isLocalScreenShare,
            'room-controls__screen-share-button--share-off': isScreenSharing && isLocalScreenShare,
          })}
        />
        <label htmlFor='room-controls__screen-share-button'>
          {isLocalScreenShare ? 'Stop Sharing' : 'Share Screen'}
        </label>
      </button>
      <button className='room-controls__leave-button room-controls__control-button' onClick={leaveAction}>
        <label htmlFor='room-controls__leave-button'>Leave</label>
      </button>
    </>
  )
}
